<?php
/*
Plugin Name: Headliner
Description: Related podcast episodes widget
Version: 0.5.2
Author: Headliner, SlipFire
Author URI: https://www.headliner.app/disco
Text Domain: headliner
License: GPLv2
*/


add_filter( 'the_content', 'headliner_div' );
add_action( 'wp_footer', 'headliner_load_script' );


/**
 * Make sure we only run on single posts
 *
 * @param [type] $content
 *
 * @return bool
 */
function headliner_check_for_single_posts() {
	return is_single() && is_main_query();
}

/**
 * Show Headliner div
 *
 * @return void
 */
function headliner_div( $content ) {
	if ( ! headliner_check_for_single_posts() ) {
		return $content;
	}

	$widget_id = get_option( 'headliner_plugin_options' )['widget_id'];
	if ( empty( $widget_id ) ) {
		return $content;
	}

	return $content . '<div class="disco-widget" data-widget-id="' . $widget_id . '"></div>' . "\n";
}


/**
 * Load Headliner JS in footer
 */
function headliner_load_script() {
	if ( ! headliner_check_for_single_posts() ) {
		return;
	}

	$widget_id = get_option( 'headliner_plugin_options' )['widget_id'];
	if ( empty( $widget_id ) ) {
		return;
	}
	?>

	<script defer src="https://disco.headliner.link/d/web/js/widget.js"></script>

	<?php
}

// Create a new options page for Headliner
add_action( 'admin_menu', 'headliner_menu' );
function headliner_menu() {
	add_options_page( __( 'Headliner', 'headliner' ), __( 'Headliner', 'headliner' ), 'manage_options', 'headliner', 'headliner_render_settings_page' );
}

function headliner_render_settings_page() {
	?>
	<form action="options.php" method="post">
		<?php
		settings_fields( 'headliner_plugin_options' );
		do_settings_sections( 'headliner_plugin' );
		?>
		<input name="submit" class="button button-primary" type="submit" value="<?php esc_attr_e( 'Save', 'headliner' ); ?>">
	</form>
	<?php
}

function headline_register_settings() {
	register_setting( 'headliner_plugin_options', 'headliner_plugin_options', 'headliner_plugin_options_validate' );
	add_settings_section( 'widget_settings', __( 'Headliner Widget Settings', 'headliner' ), 'headline_section_text', 'headliner_plugin' );

	add_settings_field( 'headline_widget_id', __( 'Widget ID', 'headliner' ), 'headline_widget_id', 'headliner_plugin', 'widget_settings' );
}

add_action( 'admin_init', 'headline_register_settings' );

function headline_section_text() {
	echo '';
}

function headline_widget_id() {
	$options = get_option( 'headliner_plugin_options' );
	echo "<input id='headline_widget_id' name='headliner_plugin_options[widget_id]' type='text' value='" . esc_attr( $options['widget_id'] ) . "' />";
}